==> haskell-crypton-conduit-0.2.3-47-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-AnUWKsVS8esBwVrlWorZ4F
key:                  crypton-conduit-0.2.3-AnUWKsVS8esBwVrlWorZ4F
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  a1986afb6e32bfd614017464d82780ae
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-AnUWKsVS8esBwVrlWorZ4F
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-extra-1.3.6-AEwfYIT97IN5iosArwGxsb
    crypton-0.34-9KzctTIsYlw5xU7XeDFfxs exceptions-0.10.4
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-conduit-0.2.3-61-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-5arhB9cdZ98ImjVBHxBMrf
key:                  crypton-conduit-0.2.3-5arhB9cdZ98ImjVBHxBMrf
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  47ff0b7c936c42e63c6cd7162319cf74
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-5arhB9cdZ98ImjVBHxBMrf
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD
    crypton-0.34-67uX59Sjjsw2dJbbUWUzWH exceptions-0.10.4
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
